<?php

namespace App\Filament\Resources;

use App\Filament\Resources\BannerSlideResource\Pages;
use App\Filament\Resources\BannerSlideResource\RelationManagers;
use App\Models\BannerSlide;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class BannerSlideResource extends Resource
{
    protected static ?string $model = BannerSlide::class;

    protected static ?string $navigationIcon = 'heroicon-o-square-2-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('title')
                    ->label('Title')
                    ->required(),
                Forms\Components\TextInput::make('description'),
                Forms\Components\TextInput::make('headline'),
                Forms\Components\FileUpload::make('image')
                    ->image()
                    ->directory('banner_slides')
                    ->required(),
                Forms\Components\TextInput::make('link'),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\ImageColumn::make('image')
                    ->label('Image'),
                Tables\Columns\TextColumn::make('title'),
                Tables\Columns\TextColumn::make('description')
                    ->wrap(),
                Tables\Columns\TextColumn::make('headline'),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListBannerSlides::route('/'),
            'create' => Pages\CreateBannerSlide::route('/create'),
            'edit' => Pages\EditBannerSlide::route('/{record}/edit'),
        ];
    }
}
