<?php

namespace App\Filament\Resources;

use App\Filament\Resources\RouteResource\Pages;
use App\Filament\Resources\RouteResource\RelationManagers;
use App\Models\Route;
use Filament\Forms;
use Filament\Forms\Components\Repeater;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class RouteResource extends Resource
{
    protected static ?string $model = Route::class;

    protected static ?string $navigationIcon = 'heroicon-o-rocket-launch';

    protected static ?string $navigationGroup = 'Transport';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\Select::make('from_id')
                    ->relationship('from', 'title')
                    ->label('Berangkat')
                    ->required(),

                Forms\Components\Select::make('destination_id')
                    ->relationship('destination', 'title')
                    ->label('Tujuan')
                    ->required(),

                Forms\Components\TimePicker::make('origin_time')
                    ->label('Waktu Berangkat')
                    ->required(),

                Forms\Components\TimePicker::make('destination_time')
                    ->label('Waktu Tiba')
                    ->required(),

                Forms\Components\TextInput::make('estimated_time')
                    ->hidden()
                    ->prefix('Waktu'),

                Forms\Components\TextInput::make('distance')
                    ->label('Jarak')
                    ->numeric()
                    ->suffix(' km'),

                Forms\Components\Select::make('seat_id')
                    ->relationship('seat', 'seat_number')
                    ->label('Nomor Kursi')
                    ->required(),

                Forms\Components\TextInput::make('price')
                    ->label('Harga')
                    ->numeric()
                    ->prefix('Rp'),

                Forms\Components\TextInput::make('price_discount')
                    ->label('Harga Diskon')
                    ->numeric()
                    ->prefix('Rp'),

                Forms\Components\Select::make('status')
                    ->options([
                        'available' => 'Available',
                        'booked' => 'Booked',
                        'reserved' => 'Reserved',
                        'damaged' => 'Damaged'
                    ])
                    ->default('available')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('from.city.name')
                    ->label('Berangkat')
                    ->searchable()
                    ->sortable()
                    ->wrap(),

                Tables\Columns\TextColumn::make('destination.city.name')
                    ->label('Tujuan')
                    ->searchable()
                    ->sortable()
                    ->wrap(),

                Tables\Columns\TextColumn::make('origin_time')
                    ->label('Wkt Bkt')
                    ->time('H:i'),

                Tables\Columns\TextColumn::make('destination_time')
                    ->label('Wkt Tiba')
                    ->time('H:i'),

                Tables\Columns\TextColumn::make('estimated_time')
                    ->label('Waktu Tempuh')
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->formatStateUsing(fn($record) => $record->estimated_time), // Panggil mutator

                Tables\Columns\TextColumn::make('distance')
                    ->label('Jarak')
                    ->numeric()
                    ->suffix(' km')
                    ->toggleable(isToggledHiddenByDefault: true),

                Tables\Columns\TextColumn::make('seat.seat_number')
                    ->label('Kursi')
                    ->searchable()
                    ->sortable(),

                Tables\Columns\TextColumn::make('price')
                    ->label('Harga')
                    ->numeric()
                    ->prefix('Rp '),

                Tables\Columns\TextColumn::make('price_discount')
                    ->label('Diskon')
                    ->numeric()
                    ->prefix('Rp '),

                Tables\Columns\TextColumn::make('status')
                    ->badge()
                    ->color(fn(string $state): string => match ($state) {
                        'available' => 'success',
                        'booked' => 'danger',
                        'reserved' => 'warning',
                        'damaged' => 'gray'
                    }),

            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make()
                    ->button()
                    ->label(''),
                Tables\Actions\ViewAction::make()
                    ->button()
                    ->label('')
                    ->color('success'),
                Tables\Actions\DeleteAction::make()
                    ->button()
                    ->label(''),

            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListRoutes::route('/'),
            'create' => Pages\CreateRoute::route('/create'),
            'edit' => Pages\EditRoute::route('/{record}/edit'),
        ];
    }
}
