<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;

class Route extends Model
{
    protected $guarded = [];

    public function schedules()
    {
        return $this->hasMany(Schedule::class);
    }

    public function from()
    {
        return $this->belongsTo(from::class, 'from_id');
    }

    public function destination()
    {
        return $this->belongsTo(Destination::class, 'destination_id');
    }

    public function seat()
    {
        return $this->belongsTo(Seat::class, 'seat_id');
    }

    // Mutator untuk menghitung estimasi waktu otomatis
    public function getEstimatedTimeAttribute()
    {
        if (!$this->origin_time || !$this->destination_time) {
            return null;
        }

        $origin = Carbon::parse($this->origin_time);
        $destination = Carbon::parse($this->destination_time);

        $diffInMinutes = $origin->diffInMinutes($destination);

        return floor($diffInMinutes / 60) . ',' . ($diffInMinutes % 60) . ' jam';
    }

    public function getSeatColorAttribute(): string
    {
        return match($this->status) {
            'available' => '#4ade80',
            'booked' => '#ef4444',
            'reserved' => '#f59e0b',
            'damaged' => '#64748b',
            default => '#4ade80'
        };
    }
}
